==> deark-1.5.9.tar.gz: deark-1.5.9/src/deark-modules.h <==
// This file is part of Deark.
// Copyright (C) 2016 Jason Summers
// See the file COPYING for terms of use.

// When you add a module, list it in this file.

// This file is #included twice by deark-modules.c, with different definitions
// of the DE_MODULE* macros.
// This technique is ugly, but it makes it simpler to add a module.

// The order that modules appear in this list can affect performance, and
// in some cases can affect what format a file will be detected as.
// The more common and easily-identified a format is, the earlier it should
// appear.

DE_MODULE(de_module_jpeg)
DE_MODULE(de_module_tiff)
DE_MODULE(de_module_gif)
DE_MODULE(de_module_bmp)
DE_MODULE(de_module_psd)
DE_MODULE(de_module_png)
DE_MODULE(de_module_cfb)
DE_MODULE(de_module_applesd)
DE_MODULE(de_module_gzip)
DE_MODULE(de_module_jpeg2000)
DE_MODULE(de_module_cab)
DE_MODULE(de_module_hlp)
DE_MODULE(de_module_rpm)
DE_MODULE(de_module_asf)
DE_MODULE(de_module_ebml)
DE_MODULE(de_module_stuffit)
DE_MODULE(de_module_icns)
DE_MODULE(de_module_ilbm)
DE_MODULE(de_module_pcx)
DE_MODULE(de_module_eps)
DE_MODULE(de_module_wmf)
DE_MODULE(de_module_emf)
DE_MODULE(de_module_midi)
DE_MODULE(de_module_corel_ccx)
DE_MODULE(de_module_sunras)
DE_MODULE(de_module_exe)
DE_MODULE(de_module_riff)
DE_MODULE(de_module_iff)
DE_MODULE(de_module_bmff)
DE_MODULE(de_module_j2c)
DE_MODULE(de_module_farbfeld)
DE_MODULE(de_module_nie)
DE_MODULE(de_module_tar)
DE_MODULE(de_module_pcpaint)
DE_MODULE(de_module_os2bmp)
DE_MODULE(de_module_id3)
DE_MODULE(de_module_ogg)
DE_MODULE(de_module_flac)
DE_MODULE(de_module_mpegaudio)
DE_MODULE(de_module_monkeys_audio)
DE_MODULE(de_module_rm)
DE_MODULE(de_module_mscompress)
DE_MODULE(de_module_wpg)
DE_MODULE(de_module_car_lha)
DE_MODULE(de_module_lha)
DE_MODULE(de_module_swg)
DE_MODULE(de_module_arx)
DE_MODULE(de_module_zoo)
DE_MODULE(de_module_zoo_filter)
DE_MODULE(de_module_zoo_z)
DE_MODULE(de_module_binhex)
DE_MODULE(de_module_anim)
DE_MODULE(de_module_jbf)
DE_MODULE(de_module_dcx)
DE_MODULE(de_module_bpg)
DE_MODULE(de_module_pnm)
DE_MODULE(de_module_ar)
DE_MODULE(de_module_cpio)
DE_MODULE(de_module_wri)
DE_MODULE(de_module_msp)
DE_MODULE(de_module_epocimage)
DE_MODULE(de_module_psionpic)
DE_MODULE(de_module_psionapp)
DE_MODULE(de_module_arcfs)
DE_MODULE(de_module_dsstore)
DE_MODULE(de_module_bmi)
DE_MODULE(de_module_mrw)
DE_MODULE(de_module_zip)
DE_MODULE(de_module_tga)
DE_MODULE(de_module_dwc)
DE_MODULE(de_module_pict)
DE_MODULE(de_module_ico)
DE_MODULE(de_module_fli)
DE_MODULE(de_module_arj)
DE_MODULE(de_module_is_z)
DE_MODULE(de_module_amigaicon)
DE_MODULE(de_module_amiga_adf)
DE_MODULE(de_module_amiga_dms)
DE_MODULE(de_module_woz)
DE_MODULE(de_module_sauce)
DE_MODULE(de_module_xbin)
DE_MODULE(de_module_ansiart)
DE_MODULE(de_module_bintext)
DE_MODULE(de_module_icedraw)
DE_MODULE(de_module_sis)
DE_MODULE(de_module_hsiraw)
DE_MODULE(de_module_gemraster)
DE_MODULE(de_module_pgc)
DE_MODULE(de_module_pgx)
DE_MODULE(de_module_fnt)
DE_MODULE(de_module_uuencode)
DE_MODULE(de_module_ascii85)
DE_MODULE(de_module_hpicn)
DE_MODULE(de_module_hpi)
DE_MODULE(de_module_flif)
DE_MODULE(de_module_psf)
DE_MODULE(de_module_nol)
DE_MODULE(de_module_ngg)
DE_MODULE(de_module_npm)
DE_MODULE(de_module_nlm)
DE_MODULE(de_module_nsl)
DE_MODULE(de_module_abk)
DE_MODULE(de_module_amos_source)
DE_MODULE(de_module_mbk)
DE_MODULE(de_module_pff2)
DE_MODULE(de_module_tivariable)
DE_MODULE(de_module_olpc565)
DE_MODULE(de_module_awbm)
DE_MODULE(de_module_lss16)
DE_MODULE(de_module_atr)
DE_MODULE(de_module_t64)
DE_MODULE(de_module_cardfile)
DE_MODULE(de_module_graspgl)
DE_MODULE(de_module_compress)
DE_MODULE(de_module_zlib)
DE_MODULE(de_module_tim)
DE_MODULE(de_module_drhalocut)
DE_MODULE(de_module_makichan)
DE_MODULE(de_module_crg)
DE_MODULE(de_module_zbr)
DE_MODULE(de_module_cdr_wl)
DE_MODULE(de_module_corel_clb)
DE_MODULE(de_module_corel_bmf)
DE_MODULE(de_module_animatic)
DE_MODULE(de_module_iim)
DE_MODULE(de_module_deskmate_pnt)
DE_MODULE(de_module_iso9660)
DE_MODULE(de_module_spark)
DE_MODULE(de_module_arc)
DE_MODULE(de_module_arcmac)
DE_MODULE(de_module_squeeze)
DE_MODULE(de_module_crunch)
DE_MODULE(de_module_crlzh)
DE_MODULE(de_module_zsq)
DE_MODULE(de_module_bsave)
DE_MODULE(de_module_xpuzzle)
DE_MODULE(de_module_autocad_slb)
DE_MODULE(de_module_plist)
DE_MODULE(de_module_grob)
DE_MODULE(de_module_shg)
DE_MODULE(de_module_alias_pix)
DE_MODULE(de_module_prismpaint)
DE_MODULE(de_module_squash)
DE_MODULE(de_module_packdir)
DE_MODULE(de_module_lbr)
DE_MODULE(de_module_pack)
DE_MODULE(de_module_atari_cas)
DE_MODULE(de_module_msa)
DE_MODULE(de_module_pasti)
DE_MODULE(de_module_vbm)
DE_MODULE(de_module_winzle)
DE_MODULE(de_module_bob)
DE_MODULE(de_module_hr)
DE_MODULE(de_module_applevol)
DE_MODULE(de_module_basic_c64)
DE_MODULE(de_module_mswordscr)
DE_MODULE(de_module_ps_gradient)
DE_MODULE(de_module_ps_styles)
DE_MODULE(de_module_ps_action)
DE_MODULE(de_module_ps_brush)
DE_MODULE(de_module_ps_csh)
DE_MODULE(de_module_ps_pattern)
DE_MODULE(de_module_rsc)
DE_MODULE(de_module_gemmeta)
DE_MODULE(de_module_pcf)
DE_MODULE(de_module_fp_art)
DE_MODULE(de_module_pf_pgf)
DE_MODULE(de_module_qtif)
DE_MODULE(de_module_degas)
DE_MODULE(de_module_tinystuff)
DE_MODULE(de_module_spectrum512u)
DE_MODULE(de_module_spectrum512s)
DE_MODULE(de_module_spectrum512c)
DE_MODULE(de_module_doodle)
DE_MODULE(de_module_neochrome)
DE_MODULE(de_module_neochrome_ani)
DE_MODULE(de_module_iccprofile)
DE_MODULE(de_module_iptc)
DE_MODULE(de_module_ripicon)
DE_MODULE(de_module_gws_thn)
DE_MODULE(de_module_insetpix)
DE_MODULE(de_module_macbinary)
DE_MODULE(de_module_macpaint)
DE_MODULE(de_module_printshop)
DE_MODULE(de_module_newprintshop)
DE_MODULE(de_module_printmaster)
DE_MODULE(de_module_pp_gph)
DE_MODULE(de_module_rosprite)
DE_MODULE(de_module_rodraw)
DE_MODULE(de_module_palmdb)
DE_MODULE(de_module_palmrc)
DE_MODULE(de_module_macrsrc)
DE_MODULE(de_module_fat)
DE_MODULE(de_module_loaddskf)
DE_MODULE(de_module_ea_data)
DE_MODULE(de_module_wad)
DE_MODULE(de_module_crush)
DE_MODULE(de_module_eggpaint)
DE_MODULE(de_module_indypaint)
DE_MODULE(de_module_godpaint)
DE_MODULE(de_module_ftc)
DE_MODULE(de_module_pkfont)
DE_MODULE(de_module_graspfont)
DE_MODULE(de_module_gemfont)
DE_MODULE(de_module_xface)
DE_MODULE(de_module_mdesk_icn)
DE_MODULE(de_module_animator_pic)
DE_MODULE(de_module_pkm)
DE_MODULE(de_module_dclimplode)
DE_MODULE(de_module_vort)
DE_MODULE(de_module_ybm)
DE_MODULE(de_module_qdv)
DE_MODULE(de_module_jovianvi)
DE_MODULE(de_module_vitec)
DE_MODULE(de_module_palmbitmap)
DE_MODULE(de_module_fpaint_pi4)
DE_MODULE(de_module_fpaint_pi9)
DE_MODULE(de_module_atari_pi7)
DE_MODULE(de_module_falcon_xga)
DE_MODULE(de_module_coke)
DE_MODULE(de_module_videomaster)
DE_MODULE(de_module_alphabmp)
DE_MODULE(de_module_dib)
DE_MODULE(de_module_win1ico)
DE_MODULE(de_module_artworx_adf)
DE_MODULE(de_module_lumena_cel)
DE_MODULE(de_module_pm_xv)
DE_MODULE(de_module_bld)
DE_MODULE(de_module_megapaint_pat)
DE_MODULE(de_module_megapaint_lib)
DE_MODULE(de_module_dlmaker)
DE_MODULE(de_module_nrg)
DE_MODULE(de_module_apm)
DE_MODULE(de_module_cd_raw)
DE_MODULE(de_module_hfs)
DE_MODULE(de_module_compfacei)
DE_MODULE(de_module_hs2)
DE_MODULE(de_module_apetag)
DE_MODULE(de_module_afcp)
DE_MODULE(de_module_lzwcom)
DE_MODULE(de_module_unifont_hex)
DE_MODULE(de_module_xxencode)
DE_MODULE(de_module_d64)
DE_MODULE(de_module_base64)
DE_MODULE(de_module_base16)
DE_MODULE(de_module_jpegscan)
DE_MODULE(de_module_ole1)
DE_MODULE(de_module_olepropset)
DE_MODULE(de_module_officeart)
DE_MODULE(de_module_ddb)
DE_MODULE(de_module_vgafont)
DE_MODULE(de_module_crc)
DE_MODULE(de_module_hexdump)
DE_MODULE(de_module_bytefreq)
DE_MODULE(de_module_plaintext)
DE_MODULE(de_module_cp437)
DE_MODULE(de_module_copy)
DE_MODULE(de_module_split)
DE_MODULE(de_module_null)
DE_MODULE_LAST(de_module_unsupported)

==> deark-1.6.2.tar.gz: deark-1.6.2/src/deark-modules.h <==
// This file is part of Deark.
// Copyright (C) 2016 Jason Summers
// See the file COPYING for terms of use.

// When you add a module, list it in this file.

// This file is #included twice by deark-modules.c, with different definitions
// of the DE_MODULE* macros.
// This technique is ugly, but it makes it simpler to add a module.

// The order that modules appear in this list can affect performance, and
// in some cases can affect what format a file will be detected as.
// The more common and easily-identified a format is, the earlier it should
// appear.

DE_MODULE(de_module_jpeg)
DE_MODULE(de_module_tiff)
DE_MODULE(de_module_gif)
DE_MODULE(de_module_bmp)
DE_MODULE(de_module_psd)
DE_MODULE(de_module_png)
DE_MODULE(de_module_cfb)
DE_MODULE(de_module_applesd)
DE_MODULE(de_module_gzip)
DE_MODULE(de_module_jpeg2000)
DE_MODULE(de_module_cab)
DE_MODULE(de_module_hlp)
DE_MODULE(de_module_rpm)
DE_MODULE(de_module_asf)
DE_MODULE(de_module_ebml)
DE_MODULE(de_module_stuffit)
DE_MODULE(de_module_icns)
DE_MODULE(de_module_ilbm)
DE_MODULE(de_module_pcx)
DE_MODULE(de_module_eps)
DE_MODULE(de_module_wmf)
DE_MODULE(de_module_emf)
DE_MODULE(de_module_midi)
DE_MODULE(de_module_corel_ccx)
DE_MODULE(de_module_sunras)
DE_MODULE(de_module_exe)
DE_MODULE(de_module_riff)
DE_MODULE(de_module_iff)
DE_MODULE(de_module_bmff)
DE_MODULE(de_module_j2c)
DE_MODULE(de_module_farbfeld)
DE_MODULE(de_module_nie)
DE_MODULE(de_module_tar)
DE_MODULE(de_module_pcpaint)
DE_MODULE(de_module_os2bmp)
DE_MODULE(de_module_id3)
DE_MODULE(de_module_ogg)
DE_MODULE(de_module_flac)
DE_MODULE(de_module_mpegaudio)
DE_MODULE(de_module_monkeys_audio)
DE_MODULE(de_module_rm)
DE_MODULE(de_module_mscompress)
DE_MODULE(de_module_wpg)
DE_MODULE(de_module_car_lha)
DE_MODULE(de_module_lha)
DE_MODULE(de_module_swg)
DE_MODULE(de_module_arx)
DE_MODULE(de_module_zoo)
DE_MODULE(de_module_zoo_filter)
DE_MODULE(de_module_zoo_z)
DE_MODULE(de_module_binhex)
DE_MODULE(de_module_anim)
DE_MODULE(de_module_jbf)
DE_MODULE(de_module_dcx)
DE_MODULE(de_module_bpg)
DE_MODULE(de_module_pnm)
DE_MODULE(de_module_ar)
DE_MODULE(de_module_cpio)
DE_MODULE(de_module_wri)
DE_MODULE(de_module_msp)
DE_MODULE(de_module_epocimage)
DE_MODULE(de_module_psionpic)
DE_MODULE(de_module_psionapp)
DE_MODULE(de_module_arcfs)
DE_MODULE(de_module_dsstore)
DE_MODULE(de_module_bmi)
DE_MODULE(de_module_mrw)
DE_MODULE(de_module_zip)
DE_MODULE(de_module_tga)
DE_MODULE(de_module_dwc)
DE_MODULE(de_module_tscomp)
DE_MODULE(de_module_pict)
DE_MODULE(de_module_ico)
DE_MODULE(de_module_clp)
DE_MODULE(de_module_fli)
DE_MODULE(de_module_arj)
DE_MODULE(de_module_is_z)
DE_MODULE(de_module_amigaicon)
DE_MODULE(de_module_amiga_adf)
DE_MODULE(de_module_amiga_dms)
DE_MODULE(de_module_woz)
DE_MODULE(de_module_sauce)
DE_MODULE(de_module_xbin)
DE_MODULE(de_module_ansiart)
DE_MODULE(de_module_bintext)
DE_MODULE(de_module_icedraw)
DE_MODULE(de_module_sis)
DE_MODULE(de_module_hsiraw)
DE_MODULE(de_module_gemraster)
DE_MODULE(de_module_pgc)
DE_MODULE(de_module_pgx)
DE_MODULE(de_module_fnt)
DE_MODULE(de_module_uuencode)
DE_MODULE(de_module_ascii85)
DE_MODULE(de_module_hpicn)
DE_MODULE(de_module_hpi)
DE_MODULE(de_module_flif)
DE_MODULE(de_module_psf)
DE_MODULE(de_module_nol)
DE_MODULE(de_module_ngg)
DE_MODULE(de_module_npm)
DE_MODULE(de_module_nlm)
DE_MODULE(de_module_nsl)
DE_MODULE(de_module_abk)
DE_MODULE(de_module_amos_source)
DE_MODULE(de_module_mbk)
DE_MODULE(de_module_pff2)
DE_MODULE(de_module_tivariable)
DE_MODULE(de_module_olpc565)
DE_MODULE(de_module_awbm)
DE_MODULE(de_module_lss16)
DE_MODULE(de_module_atr)
DE_MODULE(de_module_t64)
DE_MODULE(de_module_cardfile)
DE_MODULE(de_module_graspgl)
DE_MODULE(de_module_compress)
DE_MODULE(de_module_zlib)
DE_MODULE(de_module_deflate)
DE_MODULE(de_module_tim)
DE_MODULE(de_module_drhalocut)
DE_MODULE(de_module_makichan)
DE_MODULE(de_module_cserve_rle)
DE_MODULE(de_module_lotus_mscr)
DE_MODULE(de_module_crg)
DE_MODULE(de_module_zbr)
DE_MODULE(de_module_cdr_wl)
DE_MODULE(de_module_corel_clb)
DE_MODULE(de_module_corel_bmf)
DE_MODULE(de_module_animatic)
DE_MODULE(de_module_iim)
DE_MODULE(de_module_deskmate_pnt)
DE_MODULE(de_module_iso9660)
DE_MODULE(de_module_spark)
DE_MODULE(de_module_arc)
DE_MODULE(de_module_arcmac)
DE_MODULE(de_module_squeeze)
DE_MODULE(de_module_crunch)
DE_MODULE(de_module_crlzh)
DE_MODULE(de_module_zsq)
DE_MODULE(de_module_cpshrink)
DE_MODULE(de_module_edi_pack)
DE_MODULE(de_module_lharc_sfx_com)
DE_MODULE(de_module_pklite)
DE_MODULE(de_module_bsave)
DE_MODULE(de_module_xpuzzle)
DE_MODULE(de_module_autocad_slb)
DE_MODULE(de_module_plist)
DE_MODULE(de_module_grob)
DE_MODULE(de_module_shg)
DE_MODULE(de_module_alias_pix)
DE_MODULE(de_module_prismpaint)
DE_MODULE(de_module_squash)
DE_MODULE(de_module_packdir)
DE_MODULE(de_module_lbr)
DE_MODULE(de_module_pack)
DE_MODULE(de_module_atari_cas)
DE_MODULE(de_module_msa)
DE_MODULE(de_module_pasti)
DE_MODULE(de_module_vbm)
DE_MODULE(de_module_winzle)
DE_MODULE(de_module_pcrfont)
DE_MODULE(de_module_bob)
DE_MODULE(de_module_hr)
DE_MODULE(de_module_applevol)
DE_MODULE(de_module_basic_c64)
DE_MODULE(de_module_mswordscr)
DE_MODULE(de_module_ps_gradient)
DE_MODULE(de_module_ps_styles)
DE_MODULE(de_module_ps_action)
DE_MODULE(de_module_ps_brush)
DE_MODULE(de_module_ps_csh)
DE_MODULE(de_module_ps_pattern)
DE_MODULE(de_module_rsc)
DE_MODULE(de_module_gemmeta)
DE_MODULE(de_module_pcf)
DE_MODULE(de_module_fp_art)
DE_MODULE(de_module_pf_pgf)
DE_MODULE(de_module_qtif)
DE_MODULE(de_module_degas)
DE_MODULE(de_module_tinystuff)
DE_MODULE(de_module_spectrum512u)
DE_MODULE(de_module_spectrum512s)
DE_MODULE(de_module_spectrum512c)
DE_MODULE(de_module_doodle)
DE_MODULE(de_module_neochrome)
DE_MODULE(de_module_neochrome_ani)
DE_MODULE(de_module_iccprofile)
DE_MODULE(de_module_iptc)
DE_MODULE(de_module_ripicon)
DE_MODULE(de_module_gws_thn)
DE_MODULE(de_module_insetpix)
DE_MODULE(de_module_macbinary)
DE_MODULE(de_module_macpaint)
DE_MODULE(de_module_printshop)
DE_MODULE(de_module_newprintshop)
DE_MODULE(de_module_printmaster)
DE_MODULE(de_module_pp_gph)
DE_MODULE(de_module_rosprite)
DE_MODULE(de_module_rodraw)
DE_MODULE(de_module_palmdb)
DE_MODULE(de_module_macrsrc)
DE_MODULE(de_module_fat)
DE_MODULE(de_module_loaddskf)
DE_MODULE(de_module_ea_data)
DE_MODULE(de_module_wad)
DE_MODULE(de_module_crush)
DE_MODULE(de_module_eggpaint)
DE_MODULE(de_module_indypaint)
DE_MODULE(de_module_godpaint)
DE_MODULE(de_module_ftc)
DE_MODULE(de_module_pkfont)
DE_MODULE(de_module_graspfont)
DE_MODULE(de_module_gemfont)
DE_MODULE(de_module_xface)
DE_MODULE(de_module_mdesk_icn)
DE_MODULE(de_module_animator_pic)
DE_MODULE(de_module_young_picasso)
DE_MODULE(de_module_dgi)
DE_MODULE(de_module_cdi_imag)
DE_MODULE(de_module_storyboard)
DE_MODULE(de_module_adex)
DE_MODULE(de_module_pkm)
DE_MODULE(de_module_dclimplode)
DE_MODULE(de_module_ar001)
DE_MODULE(de_module_vort)
DE_MODULE(de_module_ybm)
DE_MODULE(de_module_qdv)
DE_MODULE(de_module_jovianvi)
DE_MODULE(de_module_vitec)
DE_MODULE(de_module_palmbitmap)
DE_MODULE(de_module_fpaint_pi4)
DE_MODULE(de_module_fpaint_pi9)
DE_MODULE(de_module_atari_pi7)
DE_MODULE(de_module_falcon_xga)
DE_MODULE(de_module_coke)
DE_MODULE(de_module_videomaster)
DE_MODULE(de_module_alphabmp)
DE_MODULE(de_module_kqp)
DE_MODULE(de_module_dib)
DE_MODULE(de_module_win1ico)
DE_MODULE(de_module_artworx_adf)
DE_MODULE(de_module_lumena_cel)
DE_MODULE(de_module_pm_xv)
DE_MODULE(de_module_bld)
DE_MODULE(de_module_megapaint_pat)
DE_MODULE(de_module_megapaint_lib)
DE_MODULE(de_module_dlmaker)
DE_MODULE(de_module_nrg)
DE_MODULE(de_module_apm)
DE_MODULE(de_module_cd_raw)
DE_MODULE(de_module_hfs)
DE_MODULE(de_module_compfacei)
DE_MODULE(de_module_hs2)
DE_MODULE(de_module_apetag)
DE_MODULE(de_module_afcp)
DE_MODULE(de_module_lzss_oku)
DE_MODULE(de_module_lzhuf)
DE_MODULE(de_module_lzwcom)
DE_MODULE(de_module_unifont_hex)
DE_MODULE(de_module_xxencode)
DE_MODULE(de_module_d64)
DE_MODULE(de_module_base64)
DE_MODULE(de_module_base16)
DE_MODULE(de_module_jpegscan)
DE_MODULE(de_module_ole1)
DE_MODULE(de_module_olepropset)
DE_MODULE(de_module_officeart)
DE_MODULE(de_module_exepack)
DE_MODULE(de_module_lzexe)
DE_MODULE(de_module_ddb)
DE_MODULE(de_module_vgafont)
DE_MODULE(de_module_crc)
DE_MODULE(de_module_hexdump)
DE_MODULE(de_module_bytefreq)
DE_MODULE(de_module_plaintext)
DE_MODULE(de_module_cp437)
DE_MODULE(de_module_copy)
DE_MODULE(de_module_xor)
DE_MODULE(de_module_split)
DE_MODULE(de_module_null)
DE_MODULE_LAST(de_module_unsupported)
